// TableComponent.tsx

import React from 'react';
import { ChakraProvider, Table, Thead, Tbody, Tr, Th, Td, IconButton, Image } from '@chakra-ui/react';
import Delete from "../assets/delete_button.svg"
import Edit from "../assets/edit_button.svg"


interface VehicleData {
  id: number;
  vehicle: string;
  mileage: string;
  plate: string;
  type: string;
  lastService: string;
  status: boolean; // Assuming status is a boolean
}

interface TableProps {
  data: VehicleData[];
  handleEdit?: (id: number) => void; // Optional edit handler
  handleDelete?: (id: number) => void; // Optional delete handler
}

const TableComponent: React.FC<TableProps> = ({ data, handleEdit, handleDelete }) => {
  return (
    <ChakraProvider>
      <Table variant="striped" colorScheme="gray" size="lg" bg="white" borderRadius="lg">
        <Thead>
          <Tr>
            <Th>ID</Th>
            <Th>Kendaraan</Th>
            <Th>Mileage</Th>
            <Th>Plat Kend.</Th>
            <Th>Jenis</Th>
            <Th>Last Service</Th>
            <Th>Status Kend.</Th>
            <Th>Actions</Th>
          </Tr>
        </Thead>
        <Tbody>
          {data.map((vehicle) => (
            <Tr key={vehicle.id}>
              <Td>{vehicle.id}</Td>
              <Td>{vehicle.vehicle}</Td>
              <Td>{vehicle.mileage}</Td>
              <Td>{vehicle.plate}</Td>
              <Td>{vehicle.type}</Td>
              <Td>{vehicle.lastService}</Td>
              <Td>{vehicle.status ? 'Active' : 'Inactive'}</Td>
              <Td>
                {/*Edit Icon*/}
                <IconButton
                  aria-label="Edit"
                  size="sm"
                  mr={2}
                  //onClick={() => handleEdit(item.ID)}
                >
                  <Image src={Edit} alt="Edit Icon" boxSize={8} />
                </IconButton>
            </Td>
            <Td>    
                {/* Delete Icon as Image */}
                <IconButton
                  aria-label="Delete"
                  size="sm"
                  //onClick={() => handleDelete(item.ID)}
                >
                  <Image src={Delete} alt="Delete Icon" boxSize={8} />
                </IconButton>
            </Td>
            </Tr>
          ))}
        </Tbody>
      </Table>
    </ChakraProvider>
  );
};

export default TableComponent;
